@@ -458,27 +458,24 @@ gsd_ldsm_purge_temp_files (GDateTime *old)
         file = g_file_new_for_path (g_get_tmp_dir ());
         data = delete_data_new (file, NULL, old, FALSE, FALSE, 0);
         delete_recursively_by_age (data);
+        delete_data_unref (data);
+        g_object_unref (file);
 
         if (g_strcmp0 (g_get_tmp_dir (), "/var/tmp") != 0) {
-                g_assert (data->ref_count == 1);
-                g_assert (data->depth == 0);
-                g_object_unref (data->file);
-                data->file = g_file_new_for_path ("/var/tmp");
-                data->depth = 0;
+                file = g_file_new_for_path ("/var/tmp");
+                data = delete_data_new (file, NULL, old, FALSE, FALSE, 0);
                 delete_recursively_by_age (data);
+                delete_data_unref (data);
+                g_object_unref (file);
         }
 
         if (g_strcmp0 (g_get_tmp_dir (), "/tmp") != 0) {
-                g_assert (data->ref_count == 1);
-                g_assert (data->depth == 0);
-                g_object_unref (data->file);
-                data->file = g_file_new_for_path ("/tmp");
-                data->depth = 0;
+                file = g_file_new_for_path ("/tmp");
+                data = delete_data_new (file, NULL, old, FALSE, FALSE, 0);
                 delete_recursively_by_age (data);
+                delete_data_unref (data);
+                g_object_unref (file);
         }
-
-        delete_data_unref (data);
-        g_object_unref (file);
 }
 
 void
