@@ -111,38 +111,6 @@ G_DEFINE_TYPE (GsdScreensaverProxyManager, gsd_screensaver_proxy_manager, G_TYPE
 
 static gpointer manager_object = NULL;
 
-#define GNOME_SESSION_DBUS_NAME      "org.gnome.SessionManager"
-#define GNOME_SESSION_DBUS_OBJECT    "/org/gnome/SessionManager"
-#define GNOME_SESSION_DBUS_INTERFACE "org.gnome.SessionManager"
-
-static GDBusProxy *
-gnome_settings_session_get_session_proxy (void)
-{
-        static GDBusProxy *session_proxy;
-        GError *error =  NULL;
-
-        if (session_proxy != NULL) {
-                g_object_ref (session_proxy);
-        } else {
-                session_proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
-                                                               G_DBUS_PROXY_FLAGS_NONE,
-                                                               NULL,
-                                                               GNOME_SESSION_DBUS_NAME,
-                                                               GNOME_SESSION_DBUS_OBJECT,
-                                                               GNOME_SESSION_DBUS_INTERFACE,
-                                                               NULL,
-                                                               &error);
-                if (error) {
-                        g_warning ("Failed to connect to the session manager: %s", error->message);
-                        g_error_free (error);
-                } else {
-                        g_object_add_weak_pointer (G_OBJECT (session_proxy), (gpointer*)&session_proxy);
-                }
-        }
-
-        return session_proxy;
-}
-
 static void
 name_vanished_cb (GDBusConnection            *connection,
                   const gchar                *name,
